@@ -2,7 +2,8 @@ from absbox.local.util import mkTag,DC,mkTs
 from enum import Enum
 import itertools
 
-from pyspecter import query
+import pandas as pd
+from pyspecter import query,S
 
 datePattern = {"月末":"MonthEnd"
               ,"季度末":"QuarterEnd"
@@ -118,6 +119,8 @@ def mkFeeType(x):
             return mkTag(("RecurFee", [mkDatePattern(p), amt]))
         case {"自定义": fflow} | {"customFee": fflow}:
             return mkTag(("FeeFlow",mkTs("BalanceCurve",fflow)))
+        case {"计数费用": [p,s,amt]} | {"numFee": [p,s,amt]}:
+            return mkTag(("NumFee",[mkDatePattern(p),mkDs(s),amt]))
         case _ :
             raise RuntimeError(f"Failed to match on fee type:{x}")
 
@@ -166,6 +169,8 @@ def mkDs(x):
             return mkTag(("LastBondIntPaid",bnds))
         case ("债券低于目标余额",bn) | ("behindTargetBalance",bn):
             return mkTag(("BondBalanceGap",bn))
+        case ("债务人数量",) | ("borrowerNumber",):
+            return mkTag(("CurrentPoolBorrowerNum"))
         
         #   , "当期已付债券利息":"LastBondIntPaid"
         #   , "当期已付费用" :"LastFeePaid"
@@ -721,11 +726,11 @@ def mkAsset(x):
                                      _statusMapping[status]]))       
         case ["分期"
             ,{"放款金额": originBalance, "放款费率": originRate, "初始期限": originTerm
-                  ,"频率": freq, "类型": _type, "放款日": startDate}
+                  ,"频率": freq, "类型": _type, "放款日": startDate, "剩余期限":remainTerms}
             ,{"当前余额":currentBalance, "状态": status}] \
             |["Installment"
             ,{"originBalance": originBalance, "feeRate": originRate, "originTerm": originTerm
-                  ,"freq": freq, "type": _type, "originDate": startDate}
+                  ,"freq": freq, "type": _type, "originDate": startDate, "remainTerm":remainTerms}
             ,{"currentBalance":currentBalance,"status": status}]:
             return mkTag(("Installment",[
                                       {"originBalance": originBalance,
@@ -736,6 +741,7 @@ def mkAsset(x):
                                       "prinType": mkAmortPlan(_type)
                                       } | mkTag("LoanOriginalInfo"),
                                      currentBalance,
+                                     remainTerms,
                                      _statusMapping[status]]))       
         case ["租赁"
                 ,{"固定租金": dailyRate, "初始期限": originTerm
@@ -946,14 +952,18 @@ def mk(x):
         #    return mkCall(calls)
 
 
-def mkComponent(x):
+def mkPricingAssump(x):
     match x:
-        case {"贴现日": pricingDay, "贴现曲线": xs}:
-            return [pricingDay, {"tag": "PricingCurve", "contents": xs}]
-        case {"PVDate": pricingDay, "PVCurve": xs}:
-            return [pricingDay, {"tag": "PricingCurve", "contents": xs}]
+        case {"贴现日": pricingDay, "贴现曲线": xs} | {"PVDate": pricingDay, "PVCurve": xs}:
+            # return [pricingDay, {"tag": "PricingCurve", "contents": xs}]
+            return mkTag(("DiscountCurve",[pricingDay, mkTs("IRateCurve",xs)]))
+        case {"债券":bnd_with_price,"利率曲线":rdps} | {"bonds":bnd_with_price,"curve":rdps}:
+            return mkTag(("RunZSpread",[mkTs("IRateCurve",rdps) ,bnd_with_price ]))
         case _:
-            None
+            raise RuntimeError(f"Failed to match pricing assumption: {x}")
+
+# "{\"tag\":\"RunZSpread\",\"contents\":[{\"tag\":\"IRateCurve\",\"contents\":[[\"2020-01-01\",1.0e-2]]}
+#                                        ,{\"A\":[\"2021-01-01\",100.3]}]}"
 
 def mkLiqProviderType(x):
     match x:
@@ -962,4 +972,21 @@ def mkLiqProviderType(x):
         case {"日期":dp, "限额":amt} | {"Reset":dp, "Quota":amt}:
             return mkTag(("ReplenishSupport", [mkDatePattern(dp),amt]))
         case {}:
-            return mkTag(("UnLimit"))            
\ No newline at end of file
+            return mkTag(("UnLimit"))            
+
+
+def readPricingResult(x, locale)->dict:
+    if x is None:
+        return None
+    h = None
+
+    tag = query(x,[S.MVALS,S.ALL,"tag"])[0]
+    if tag=="PriceResult":
+        h = {"cn": ["估值", "票面估值", "WAL", "久期", "凸性", "应计利息"],
+                "en":["pricing", "face", "WAL", "duration","convexity", "accure interest"]}
+    elif tag=="ZSpread":
+        h = {"cn":["静态利差"], "en":["Z-spread"]}
+    else:
+        raise RuntimeError(f"Failed to read princing result: {x} with tag={tag}")
+
+    return pd.DataFrame.from_dict({k:v['contents'] for k,v in x.items()} , orient='index', columns=h[locale]).sort_index()
\ No newline at end of file
